@@ -33,19 +33,41 @@
 #define PLUGIN_NAME "xfce4-notes-plugin"
 
 
-static void     note_page_load_data     (XfcePanelPlugin *, NotePage *);
-static void     on_notes_close             (GtkWidget *, NotesPlugin *);
-static gboolean on_note_window_close     ();
-static gboolean on_title_press             (GtkWidget *, GdkEventButton *, GtkWindow *);
-static gboolean on_title_scroll         (GtkWidget *, GdkEventScroll *, Note *);
-static gboolean on_note_key_press         (GtkWidget *, GdkEventKey *, NotesPlugin *);
-static void     on_note_changed         (GtkWidget *, NotesPlugin *);
-static void     note_page_rename         (Note *);
-static gboolean on_note_rename             (GtkWidget *, GdkEventButton *, Note *);
-static void     on_note_rename_response (GtkDialog *, gint response, GSList *);
-static void     on_page_create             (GtkWidget *, NotesPlugin *);
-static gboolean on_page_delete             (GtkWidget *, NotesPlugin *);
-static void     note_page_destroy         (GtkWidget *, gint response_id, NotesPlugin *);
+
+static void         note_page_load_data         (XfcePanelPlugin *, 
+                                                 NotePage *);
+static void         on_notes_close              (GtkWidget *, 
+                                                 NotesPlugin *);
+static gboolean     on_note_window_close        ();
+
+static gboolean     on_title_press              (GtkWidget *, 
+                                                 GdkEventButton *, 
+                                                 GtkWindow *);
+static gboolean     on_title_scroll             (GtkWidget *, 
+                                                 GdkEventScroll *, 
+                                                 NotesPlugin *);
+static gboolean     on_note_key_press           (GtkWidget *, 
+                                                 GdkEventKey *, 
+                                                 NotesPlugin *);
+static void         on_note_changed             (GtkWidget *, 
+                                                 NotesPlugin *);
+static void         note_page_rename            (Note *);
+
+static gboolean     on_note_rename              (GtkWidget *, 
+                                                 GdkEventButton *, 
+                                                 Note *);
+static void         on_note_rename_response     (GtkDialog *, 
+                                                 gint response, 
+                                                 GSList *);
+static void         on_page_create              (GtkWidget *, 
+                                                 NotesPlugin *);
+static gboolean     on_page_delete              (GtkWidget *, 
+                                                 NotesPlugin *);
+static void         note_page_destroy           (GtkWidget *, 
+                                                 gint response_id, 
+                                                 NotesPlugin *);
+
+
 
 Note *
 note_new (NotesPlugin *notes)
@@ -65,7 +87,7 @@ note_new (NotesPlugin *notes)
     note->window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
 
     gtk_window_set_title (GTK_WINDOW (note->window), _("Notes"));
-    gtk_window_set_default_size (GTK_WINDOW (note->window), 242, 200);
+    gtk_window_set_default_size (GTK_WINDOW (note->window), 290, 320);
     gtk_window_set_decorated (GTK_WINDOW (note->window), FALSE);
     gtk_window_set_icon_name (GTK_WINDOW (note->window), GTK_STOCK_EDIT);
     gtk_window_add_accel_group (GTK_WINDOW (note->window), accel_group);
@@ -89,7 +111,7 @@ note_new (NotesPlugin *notes)
     note->vbox = gtk_vbox_new (FALSE, 0);
     gtk_widget_show (note->vbox);
 
-    gtk_box_set_spacing (GTK_BOX (note->vbox), 2);
+    gtk_box_set_spacing (GTK_BOX (note->vbox), 1);
     gtk_container_add (GTK_CONTAINER (note->frame), note->vbox);
 
 
@@ -147,7 +169,7 @@ note_new (NotesPlugin *notes)
                       G_CALLBACK (on_title_press), note->window);
 
     g_signal_connect (G_OBJECT (note->move_event_box), "scroll-event",
-                      G_CALLBACK (on_title_scroll), note);
+                      G_CALLBACK (on_title_scroll), notes);
 
     gtk_widget_realize (note->move_event_box);
 
@@ -191,6 +213,13 @@ note_new (NotesPlugin *notes)
 
     gtk_box_pack_start (GTK_BOX (note->vbox), note->notebook, TRUE, TRUE, 0);
 
+
+    /* Status bar */
+    note->statusbar = gtk_statusbar_new ();
+    gtk_widget_show (note->statusbar);
+
+    gtk_box_pack_start (GTK_BOX (note->vbox), note->statusbar, FALSE, FALSE, 0);
+
     return note;
 }
 
@@ -260,7 +289,9 @@ note_page_load_data (XfcePanelPlugin *plugin, NotePage *page)
     gchar *file;
     XfceRc *rc;
 
-    if (!(file = xfce_panel_plugin_lookup_rc_file (plugin)))
+    file = xfce_resource_save_location (XFCE_RESOURCE_CONFIG,
+                                        "xfce4/panel/notes.rc", TRUE);
+    if (G_UNLIKELY (!file))
         return;
 
     DBG ("Look up file (%s)", file);
@@ -322,8 +353,9 @@ on_title_press (GtkWidget *widget, GdkEventButton *event, GtkWindow *window)
 }
 
 static gboolean
-on_title_scroll (GtkWidget *widget, GdkEventScroll *event, Note *note)
+on_title_scroll (GtkWidget *widget, GdkEventScroll *event, NotesPlugin *notes)
 {
+    Note *note = notes->note;
     if (event->type == GDK_SCROLL)
       {
         if (GTK_WIDGET_VISIBLE (note->notebook))
@@ -335,12 +367,15 @@ on_title_scroll (GtkWidget *widget, GdkEventScroll *event, Note *note)
           {
             /* Hide the text view */
             gtk_widget_hide (note->notebook);
+            gtk_widget_hide (note->statusbar);
             gtk_window_resize (GTK_WINDOW (note->window), note->w, 1);
           }
         else if (event->direction == GDK_SCROLL_DOWN)
           {
             /* Show the text view */
             gtk_widget_show (note->notebook);
+            if (notes->options.statusbar)
+                gtk_widget_show (note->statusbar);
             gtk_window_resize (GTK_WINDOW (note->window), note->w, note->h);
           }
       }
@@ -351,16 +386,30 @@ on_title_scroll (GtkWidget *widget, GdkEventScroll *event, Note *note)
 static gboolean
 on_note_key_press (GtkWidget *widget, GdkEventKey *event, NotesPlugin *notes)
 {
+    gint current, after;
+    GtkWidget *notebook = notes->note->notebook;
+
     if (event->type == GDK_KEY_PRESS)
       {
         if (event->keyval == GDK_Escape)
             gtk_button_clicked (GTK_BUTTON (notes->button));
         else if (event->state & GDK_CONTROL_MASK)
           {
+            current = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
             if (event->keyval == GDK_Page_Down)
-                gtk_notebook_next_page (GTK_NOTEBOOK (notes->note->notebook));
+              {
+                gtk_notebook_next_page (GTK_NOTEBOOK (notebook));
+                after = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
+                if (current == after)
+                    gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), 0);
+              }
             else if (event->keyval == GDK_Page_Up)
-                gtk_notebook_prev_page (GTK_NOTEBOOK (notes->note->notebook));
+              {
+                gtk_notebook_prev_page (GTK_NOTEBOOK (notebook));
+                after = gtk_notebook_get_current_page (GTK_NOTEBOOK (notebook));
+                if (current == after)
+                    gtk_notebook_set_current_page (GTK_NOTEBOOK (notebook), -1);
+              }
           }
         else if (event->keyval == GDK_F2)
           {
@@ -477,6 +526,9 @@ on_page_create (GtkWidget *widget, NotesPlugin *notes)
 {
     note_page_new (notes->plugin, notes);
     gtk_notebook_set_current_page (GTK_NOTEBOOK (notes->note->notebook), -1);
+    /* Show the text view */
+    gtk_widget_show (notes->note->notebook);
+    gtk_window_resize (GTK_WINDOW (notes->note->window), notes->note->w, notes->note->h);
 }
 
 static gboolean
@@ -533,7 +585,9 @@ note_page_destroy (GtkWidget *widget, gint response_id, NotesPlugin *notes)
 
         DBG ("Delete id %d", id);
 
-        if (!(file = xfce_panel_plugin_save_location (notes->plugin, TRUE)))
+        file = xfce_resource_save_location (XFCE_RESOURCE_CONFIG,
+                                            "xfce4/panel/notes.rc", TRUE);
+        if (G_UNLIKELY (!file))
             return;
 
         rc = xfce_rc_simple_open (file, FALSE);
