@@ -26,10 +26,12 @@
 
 typedef struct
 {
+    gboolean visible;
     gboolean show;
     gboolean task_switcher;
     gboolean always_on_top;
     gboolean stick;
+    gboolean statusbar;
 }
 NotesOptions;
 
